@@ -1,4 +1,4 @@
-# (C) Copyright 2015,2016 Hewlett Packard Enterprise Development Company LP
+# (C) Copyright 2015,2016 Hewlett Packard Enterprise Development LP
 """Base class for Checks.
 
 If you are writing your own checks you should subclass the AgentCheck class.
@@ -39,7 +39,6 @@ class AgentCheck(util.Dimensions):
             aggregator.MetricsAggregator(self.hostname,
                                          recent_point_threshold=threshold))
 
-        self.events = []
         self.instances = instances or []
         self.library_versions = None
 
@@ -138,48 +137,6 @@ class AgentCheck(util.Dimensions):
                                       device_name,
                                       value_meta)
 
-    def histogram(self, metric, value, dimensions=None, delegated_tenant=None,
-                  hostname=None, device_name=None, value_meta=None):
-        """Sample a histogram value, with optional dimensions, hostname and device name.
-
-        :param metric: The name of the metric
-        :param value: The value to sample for the histogram
-        :param dimensions: (optional) A dictionary of dimensions for this metric
-        :param delegated_tenant: (optional) Submit metrics on behalf of this tenant ID.
-        :param hostname: (optional) A hostname for this metric. Defaults to the current hostname.
-        :param device_name: (optional) The device name for this metric
-        :param value_meta: Additional metadata about this value
-        """
-        self.aggregator.submit_metric(metric,
-                                      value,
-                                      metrics_pkg.Histogram,
-                                      dimensions,
-                                      delegated_tenant,
-                                      hostname,
-                                      device_name,
-                                      value_meta)
-
-    def set(self, metric, value, dimensions=None, delegated_tenant=None,
-            hostname=None, device_name=None, value_meta=None):
-        """Sample a set value, with optional dimensions, hostname and device name.
-
-        :param metric: The name of the metric
-        :param value: The value for the set
-        :param dimensions: (optional) A dictionary of dimensions for this metric
-        :param delegated_tenant: (optional) Submit metrics on behalf of this tenant ID.
-        :param hostname: (optional) A hostname for this metric. Defaults to the current hostname.
-        :param device_name: (optional) The device name for this metric
-        :param value_meta: Additional metadata about this value
-        """
-        self.aggregator.submit_metric(metric,
-                                      value,
-                                      metrics_pkg.Set,
-                                      dimensions,
-                                      delegated_tenant,
-                                      hostname,
-                                      device_name,
-                                      value_meta)
-
     def get_metrics(self, prettyprint=False):
         """Get all metrics, including the ones that are tagged.
 
@@ -189,27 +146,27 @@ class AgentCheck(util.Dimensions):
         metrics = self.aggregator.flush()
         if prettyprint:
             for metric in metrics:
-                print(" Timestamp:  {0}".format(metric.timestamp))
-                print(" Name:       {0}".format(metric.name))
-                print(" Value:      {0}".format(metric.value))
-                if (metric.delegated_tenant):
-                    print(" Delegate ID: {0}".format(metric.delegated_tenant))
-
+                measurement = metric['measurement']
+                print(" Timestamp: {0}".format(measurement['timestamp']))
+                print(" Name:       {0}".format(measurement['name']))
+                print(" Value:      {0}".format(measurement['value']))
                 print(" Dimensions: ", end='')
                 line = 0
-                for name in metric.dimensions:
+                dimensions = measurement['dimensions']
+                for name in dimensions:
                     if line != 0:
                         print(" " * 13, end='')
-                    print("{0}={1}".format(name, metric.dimensions[name]))
+                    print("{0}={1}".format(name, dimensions[name]))
                     line += 1
 
                 print(" Value Meta: ", end='')
-                if metric.value_meta:
+                value_meta = measurement['value_meta']
+                if value_meta:
                     line = 0
-                    for name in metric.value_meta:
+                    for name in value_meta:
                         if line != 0:
                             print(" " * 13, end='')
-                        print("{0}={1}".format(name, metric.value_meta[name]))
+                        print("{0}={1}".format(name, value_meta[name]))
                         line += 1
                 else:
                     print('None')
