@@ -1,6 +1,6 @@
 #!/bin/env python
 
-# (c) Copyright 2014-2016 Hewlett Packard Enterprise Development Company LP
+# (c) Copyright 2014-2016 Hewlett Packard Enterprise Development LP
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -27,9 +27,9 @@ from calendar import timegm
 from copy import deepcopy
 from datetime import datetime
 from datetime import timedelta
-from distutils.version import LooseVersion
 from monasca_agent.collector.checks import AgentCheck
 from monasca_agent.collector.virt import inspector
+from multiprocessing.dummy import Pool
 from netaddr import all_matching_cidrs
 
 DOM_STATES = {libvirt.VIR_DOMAIN_BLOCKED: 'VM is blocked',
@@ -52,12 +52,20 @@ class LibvirtCheck(AgentCheck):
         self.metric_cache_file = "{0}/{1}".format(self.init_config.get('cache_dir'),
                                                   'libvirt_metrics.json')
         self.use_bits = self.init_config.get('network_use_bits')
-        if self.init_config.get('disk_collection_period'):
-            self._disk_collection_period = int(self.init_config.get('disk_collection_period'))
-            self._last_disk_collect_time = datetime.fromordinal(1)
-        else:
-            self._disk_collection_period = 0
-        self._skip_disk_collection = False
+
+        self._collect_intervals = {}
+
+        self._set_collection_intervals('disk', 'disk_collection_period')
+        self._set_collection_intervals('vnic', 'vnic_collection_period')
+
+        pool_size = self.init_config.get('max_ping_concurrency', 8)
+        self.pool = Pool(pool_size)
+
+    def _set_collection_intervals(self, interval_name, config_name):
+        self._collect_intervals[interval_name] = {
+            'period': int(self.init_config.get(config_name, 0)),
+            'last_collect': datetime.fromordinal(1),
+            'skip': False}
 
     def _test_vm_probation(self, created):
         """Test to see if a VM was created within the probation period.
@@ -104,6 +112,7 @@ class LibvirtCheck(AgentCheck):
         """Collect instance_id, project_id, and AZ for all instance UUIDs
         """
         from novaclient import client
+        from novaclient.exceptions import NotFound
 
         id_cache = {}
         flavor_cache = {}
@@ -126,7 +135,8 @@ class LibvirtCheck(AgentCheck):
                                password=self.init_config.get('admin_password'),
                                tenant_name=self.init_config.get('admin_tenant_name'),
                                auth_url=self.init_config.get('identity_uri'),
-                               endpoint_type='internalURL')
+                               endpoint_type='internalURL',
+                               region_name=self.init_config.get('region_name'))
             port_cache = nu.list_ports()['ports']
             # Finding existing network namespaces is an indication that either
             # DVR agent_mode is enabled, or this is all-in-one (like devstack)
@@ -142,7 +152,11 @@ class LibvirtCheck(AgentCheck):
             if instance.flavor['id'] in flavor_cache:
                 inst_flavor = flavor_cache[instance.flavor['id']]
             else:
-                inst_flavor = nova_client.flavors.get(instance.flavor['id'])
+                try:
+                    inst_flavor = nova_client.flavors.get(instance.flavor['id'])
+                except NotFound as e:
+                    self.log.error('Skipping VM {}: {}'.format(inst_name, e))
+                    continue
                 flavor_cache[instance.flavor['id']] = inst_flavor
             if port_cache:
                 instance_ports = [p['id'] for p in port_cache if p['device_id'] == instance.id]
@@ -279,9 +293,8 @@ class LibvirtCheck(AgentCheck):
         except IOError as e:
             self.log.error("Cannot write to {0}: {1}".format(self.metric_cache_file, e))
 
-    def _inspect_network(self, insp, inst, instance_cache, metric_cache, dims_customer, dims_operations):
+    def _inspect_network(self, insp, inst, inst_name, instance_cache, metric_cache, dims_customer, dims_operations):
         """Inspect network metrics for an instance"""
-        inst_name = inst.name()
         for vnic in insp.inspect_vnics(inst):
             sample_time = time.time()
             vnic_dimensions = {'device': vnic[0].name}
@@ -352,13 +365,13 @@ class LibvirtCheck(AgentCheck):
                     'timestamp': sample_time,
                     'value': value}
 
-    def _inspect_cpu(self, insp, inst, instance_cache, metric_cache, dims_customer, dims_operations):
+    def _inspect_cpu(self, insp, inst, inst_name, instance_cache, metric_cache, dims_customer, dims_operations):
         """Inspect cpu metrics for an instance"""
 
-        inst_name = inst.name()
         sample_time = float("{:9f}".format(time.time()))
+        cpu_info = insp.inspect_cpus(inst)
+
         if 'cpu.time' in metric_cache[inst_name]:
-            cpu_info = insp.inspect_cpus(inst)
             # I have a prior value, so calculate the raw_perc & push the metric
             cpu_diff = cpu_info.time - metric_cache[inst_name]['cpu.time']['value']
             time_diff = sample_time - float(metric_cache[inst_name]['cpu.time']['timestamp'])
@@ -370,7 +383,7 @@ class LibvirtCheck(AgentCheck):
                 # Bad value, save current reading and skip
                 self.log.warn("Ignoring negative CPU sample for: "
                               "{0} new cpu time: {1} old cpu time: {2}"
-                              .format(inst_name, insp.inspect_cpus(inst).time,
+                              .format(inst_name, cpu_info.time,
                                       metric_cache[inst_name]['cpu.time']['value']))
                 metric_cache[inst_name]['cpu.time'] = {'timestamp': sample_time,
                                                        'value': cpu_info.time}
@@ -388,16 +401,22 @@ class LibvirtCheck(AgentCheck):
                        dimensions=dims_operations)
             self.gauge('vm.cpu.utilization_norm_perc', int(round(normalized_perc, 0)),
                        dimensions=dims_operations)
-            self.gauge('vm.cpu.time_ns', insp.inspect_cpus(inst).time,
+
+            cpu_time_name = 'cpu.time_ns'
+            # cpu.time_ns for owning tenant
+            self.gauge(cpu_time_name, cpu_info.time,
+                       dimensions=dims_customer,
+                       delegated_tenant=instance_cache.get(inst_name)['tenant_id'],
+                       hostname=instance_cache.get(inst_name)['hostname'])
+            # vm..cpu.time_ns for operations tenant
+            self.gauge("vm.{0}".format(cpu_time_name), cpu_info.time,
                        dimensions=dims_operations)
-
         metric_cache[inst_name]['cpu.time'] = {'timestamp': sample_time,
-                                               'value': insp.inspect_cpus(inst).time}
+                                               'value': cpu_info.time}
 
-    def _inspect_disks(self, insp, inst, instance_cache, metric_cache, dims_customer, dims_operations):
+    def _inspect_disks(self, insp, inst, inst_name, instance_cache, metric_cache, dims_customer, dims_operations):
         """Inspect disk metrics for an instance"""
 
-        inst_name = inst.name()
         metric_aggregate = {}
         for disk in insp.inspect_disks(inst):
             sample_time = time.time()
@@ -435,6 +454,10 @@ class LibvirtCheck(AgentCheck):
                     self.gauge(rate_name, rate_value, dimensions=this_dimensions,
                                delegated_tenant=instance_cache.get(inst_name)['tenant_id'],
                                hostname=instance_cache.get(inst_name)['hostname'])
+                    self.gauge(metric_name, value, dimensions=this_dimensions,
+                               delegated_tenant=instance_cache.get(inst_name)['tenant_id'],
+                               hostname=instance_cache.get(inst_name)['hostname'])
+
                     # Operations (metric name prefixed with "vm."
                     this_dimensions = disk_dimensions.copy()
                     this_dimensions.update(dims_operations)
@@ -447,46 +470,51 @@ class LibvirtCheck(AgentCheck):
                     'timestamp': sample_time,
                     'value': value}
 
-        this_dimensions = dict()
-        this_dimensions.update(dims_customer)
-        this_dimensions.update(dims_operations)
-        for metric in metric_aggregate:
-            sample_time = time.time()
-            rate_name = "vm.{0}_total_sec".format(metric)
-            if rate_name not in metric_cache[inst_name]:
-                metric_cache[inst_name][rate_name] = {}
-            else:
-                last_update_time = metric_cache[inst_name][
-                    rate_name]['timestamp']
-                time_diff = sample_time - float(last_update_time)
-                rate_value = self._calculate_rate(metric_aggregate[metric],
-                                                  metric_cache[inst_name][rate_name]['value'],
-                                                  time_diff)
-                if rate_value < 0:
-                    # Bad value, save current reading and skip
-                    self.log.warn("Ignoring negative disk sample for: "
-                                  "{0} new value: {1} old value: {2}"
-                                  .format(inst_name, metric_aggregate[metric],
-                                          metric_cache[inst_name][rate_name][
-                                              'value']))
-                    metric_cache[inst_name][rate_name] = {
-                        'timestamp': sample_time,
-                        'value': metric_aggregate[metric]}
-                    continue
-                self.gauge(rate_name, rate_value,
-                           dimensions=this_dimensions)
-            self.gauge("vm.{0}_total".format(metric), metric_aggregate[
-                metric], dimensions=this_dimensions)
-            # Save this metric to the cache
-            metric_cache[inst_name][rate_name] = {
-                'timestamp': sample_time,
-                'value': metric_aggregate[metric]}
+        if self.init_config.get('vm_extended_disks_check_enable'):
+            for metric in metric_aggregate:
+                sample_time = time.time()
+                rate_name = "{0}_total_sec".format(metric)
+                if rate_name not in metric_cache[inst_name]:
+                    metric_cache[inst_name][rate_name] = {}
+                else:
+                    last_update_time = metric_cache[inst_name][
+                        rate_name]['timestamp']
+                    time_diff = sample_time - float(last_update_time)
+                    rate_value = self._calculate_rate(metric_aggregate[metric],
+                                                      metric_cache[inst_name][rate_name]['value'],
+                                                      time_diff)
+                    if rate_value < 0:
+                        # Bad value, save current reading and skip
+                        self.log.warn("Ignoring negative disk sample for: "
+                                      "{0} new value: {1} old value: {2}"
+                                      .format(inst_name, metric_aggregate[metric],
+                                              metric_cache[inst_name][rate_name][
+                                                  'value']))
+                        metric_cache[inst_name][rate_name] = {
+                            'timestamp': sample_time,
+                            'value': metric_aggregate[metric]}
+                        continue
+                    self.gauge(rate_name, rate_value, dimensions=dims_customer,
+                               delegated_tenant=instance_cache.get(inst_name)['tenant_id'],
+                               hostname=instance_cache.get(inst_name)['hostname'])
+                    self.gauge("vm.{0}".format(rate_name), rate_value,
+                               dimensions=dims_operations)
+                self.gauge("{0}_total".format(metric), metric_aggregate[metric],
+                           dimensions=dims_customer,
+                           delegated_tenant=instance_cache.get(inst_name)['tenant_id'],
+                           hostname=instance_cache.get(inst_name)['hostname'])
+                self.gauge("vm.{0}_total".format(metric),
+                           metric_aggregate[metric],
+                           dimensions=dims_operations)
+                # Save this metric to the cache
+                metric_cache[inst_name][rate_name] = {
+                    'timestamp': sample_time,
+                    'value': metric_aggregate[metric]}
 
-    def _inspect_disk_info(self, insp, inst, instance_cache, metric_cache,
+    def _inspect_disk_info(self, insp, inst, inst_name, instance_cache, metric_cache,
                            dims_customer, dims_operations):
         """Inspect disk metrics for an instance"""
 
-        inst_name = inst.name()
         metric_aggregate = {}
         for disk in insp.inspect_disk_info(inst):
             disk_dimensions = {'device': disk[0].device}
@@ -506,27 +534,29 @@ class LibvirtCheck(AgentCheck):
                 self.gauge("vm.{0}".format(metric_name), value,
                            dimensions=this_dimensions)
 
-        this_dimensions = dict()
-        this_dimensions.update(dims_customer)
-        this_dimensions.update(dims_operations)
         for metric in metric_aggregate:
-            self.gauge("vm.{0}_total".format(metric), metric_aggregate[
-                metric], dimensions=this_dimensions)
+            self.gauge("{0}_total".format(metric), metric_aggregate[metric],
+                       dimensions=dims_customer,
+                       delegated_tenant=instance_cache.get(inst_name)['tenant_id'],
+                       hostname=instance_cache.get(inst_name)['hostname'])
+            self.gauge("vm.{0}_total".format(metric),
+                       metric_aggregate[metric],
+                       dimensions=dims_operations)
 
-    def _inspect_state(self, insp, inst, instance_cache, dims_customer, dims_operations):
+    def _inspect_state(self, insp, inst, inst_name, instance_cache, dims_customer, dims_operations):
         """Look at the state of the instance, publish a metric using a
            user-friendly description in the 'detail' metadata, and return
            a status code (calibrated to UNIX status codes where 0 is OK)
            so that remaining metrics can be skipped if the VM is not OK
         """
-        inst_name = inst.name()
-        dom_status = inst.state()[0] - 1
+        inst_state = inst.state()
+        dom_status = inst_state[0] - 1
         metatag = None
 
-        if inst.state()[0] in DOM_STATES:
-            metatag = {'detail': DOM_STATES[inst.state()[0]]}
+        if inst_state[0] in DOM_STATES:
+            metatag = {'detail': DOM_STATES[inst_state[0]]}
         # A nova-suspended VM has a SHUTOFF Power State, but alternate Status
-        if inst.state() == [libvirt.VIR_DOMAIN_SHUTOFF, 5]:
+        if inst_state == [libvirt.VIR_DOMAIN_SHUTOFF, 5]:
             metatag = {'detail': 'VM has been suspended'}
 
         self.gauge('host_alive_status', dom_status, dimensions=dims_customer,
@@ -540,21 +570,61 @@ class LibvirtCheck(AgentCheck):
         return dom_status
 
     def prepare_run(self):
-        """Check if it is time for the disk measurements to be collected"""
-        # A separate disk collection period is optional
-        if self._disk_collection_period <= 0:
-            return
+        """Check if it is time for measurements to be collected"""
+        for name, collection in self._collect_intervals.iteritems():
+            if collection['period'] <= 0:
+                continue
 
-        time_since_last = datetime.now() - self._last_disk_collect_time
-        # Handle times that are really close to the disk collection period
-        period_with_fudge_factor = timedelta(0, self._disk_collection_period - 1,
-                                             500000)
-        if time_since_last < period_with_fudge_factor:
-            self.log.debug('Skipping disk collection for %d seconds' %
-                           (self._disk_collection_period - time_since_last.seconds))
-            self._skip_disk_collection = True
-        else:
-            self._skip_disk_collection = False
+            time_since_last = datetime.now() - collection['last_collect']
+            # Handle times that are really close to the collection period
+            period_with_fudge_factor = timedelta(0, collection['period'] - 1,
+                                                 500000)
+
+            if time_since_last < period_with_fudge_factor:
+                self.log.debug('Skipping {} collection for {} seconds'.format(
+                               name,
+                               (collection['period'] - time_since_last.seconds)))
+                collection['skip'] = True
+            else:
+                collection['skip'] = False
+                collection['last_collect'] = datetime.now()
+
+    def _run_ping(self, dims_customer, dims_operations, inst_name, instance_cache, net):
+        """Create a ping command and hand it off to the Thread Pool"""
+        ping_cmd = self.init_config.get('ping_check').replace('NAMESPACE',
+                                                              net['namespace']).split()
+        ping_cmd.append(net['ip'])
+        dims_customer_ip = dims_customer.copy()
+        dims_operations_ip = dims_operations.copy()
+        dims_customer_ip['ip'] = net['ip']
+        dims_operations_ip['ip'] = net['ip']
+        with open(os.devnull, "w") as fnull:
+            try:
+                self.log.debug("Running ping test: {0}".format(' '.join(ping_cmd)))
+                res = subprocess.call(ping_cmd,
+                                      stdout=fnull,
+                                      stderr=fnull)
+                tenant_id = instance_cache.get(inst_name)['tenant_id']
+                hostname = instance_cache.get(inst_name)['hostname']
+                return (res, dims_customer_ip, dims_operations_ip, tenant_id,
+                        hostname)
+
+            except Exception as e:
+                self.log.exception("OS error running '{0}' failed".format(ping_cmd), e)
+                raise e
+
+    def _check_ping_results(self, ping_results):
+        """Iterate through ping results and create measurements"""
+        for result in ping_results:
+            result.wait()
+            # If it wasn't successful, a message was already logged in _run_ping
+            if result.successful():
+                (res, dims_customer_ip, dims_operations_ip, delegated_tenant,
+                 hostname) = result.get()
+                self.gauge('ping_status', res, dimensions=dims_customer_ip,
+                           delegated_tenant=delegated_tenant,
+                           hostname=hostname)
+                self.gauge('vm.ping_status', res, dimensions=dims_operations_ip)
 
     def check(self, instance):
         """Gather VM metrics for each instance"""
@@ -580,6 +650,7 @@ class LibvirtCheck(AgentCheck):
 
         insp = inspector.get_hypervisor_inspector()
         updated_cache_this_time = False
+        ping_results = []
         for inst in insp._get_connection().listAllDomains():
             # Verify that this instance exists in the cache.  Add if necessary.
             inst_name = inst.name()
@@ -626,15 +697,6 @@ class LibvirtCheck(AgentCheck):
                 if gauge in instance_cache.get(inst_name):
                     agg_values[gauge] += instance_cache.get(inst_name)[gauge]
 
-            # Skip further processing on VMs that are not in an active state
-            if self._inspect_state(insp, inst, instance_cache,
-                                   dims_customer, dims_operations) != 0:
-                continue
-
-            # Skip the remainder of the checks if alive_only is True in the config
-            if self.init_config.get('alive_only'):
-                continue
-
             # Skip instances created within the probation period
             vm_probation_remaining = self._test_vm_probation(instance_cache.get(inst_name)['created'])
             if (vm_probation_remaining >= 0):
@@ -642,30 +704,41 @@ class LibvirtCheck(AgentCheck):
                                                                                          vm_probation_remaining))
                 continue
 
+            # Skip further processing on VMs that are not in an active state
+            if self._inspect_state(insp, inst, inst_name, instance_cache,
+                                   dims_customer, dims_operations) != 0:
+                continue
+
+            # Skip the remainder of the checks if alive_only is True in the config
+            if self.init_config.get('alive_only'):
+                continue
+
             if inst_name not in metric_cache:
                 metric_cache[inst_name] = {}
 
             if self.init_config.get('vm_cpu_check_enable'):
-                self._inspect_cpu(insp, inst, instance_cache, metric_cache, dims_customer, dims_operations)
-            if not self._skip_disk_collection:
-                self._last_disk_collect_time = datetime.now()
+                self._inspect_cpu(insp, inst, inst_name, instance_cache, metric_cache, dims_customer, dims_operations)
+            if not self._collect_intervals['disk']['skip']:
                 if self.init_config.get('vm_disks_check_enable'):
-                    self._inspect_disks(insp, inst, instance_cache, metric_cache, dims_customer,
+                    self._inspect_disks(insp, inst, inst_name, instance_cache, metric_cache, dims_customer,
                                         dims_operations)
                 if self.init_config.get('vm_extended_disks_check_enable'):
-                    self._inspect_disk_info(insp, inst, instance_cache, metric_cache, dims_customer,
+                    self._inspect_disk_info(insp, inst, inst_name, instance_cache, metric_cache, dims_customer,
                                             dims_operations)
-            if self.init_config.get('vm_network_check_enable'):
-                self._inspect_network(insp, inst, instance_cache, metric_cache, dims_customer, dims_operations)
+
+            if not self._collect_intervals['vnic']['skip']:
+                if self.init_config.get('vm_network_check_enable'):
+                    self._inspect_network(insp, inst, inst_name, instance_cache, metric_cache, dims_customer, dims_operations)
 
             # Memory utilizaion
             # (req. balloon driver; Linux kernel param CONFIG_VIRTIO_BALLOON)
             try:
-                mem_metrics = {'mem.free_mb': float(inst.memoryStats()['unused']) / 1024,
-                               'mem.swap_used_mb': float(inst.memoryStats()['swap_out']) / 1024,
-                               'mem.total_mb': float(inst.memoryStats()['available'] - inst.memoryStats()['unused']) / 1024,
-                               'mem.used_mb': float(inst.memoryStats()['available'] - inst.memoryStats()['unused']) / 1024,
-                               'mem.free_perc': float(inst.memoryStats()['unused']) / float(inst.memoryStats()['available']) * 100}
+                mem_stats = inst.memoryStats()
+                mem_metrics = {'mem.free_mb': float(mem_stats['unused']) / 1024,
+                               'mem.swap_used_mb': float(mem_stats['swap_out']) / 1024,
+                               'mem.total_mb': float(mem_stats['available']) / 1024,
+                               'mem.used_mb': float(mem_stats['available'] - mem_stats['unused']) / 1024,
+                               'mem.free_perc': float(mem_stats['unused']) / float(mem_stats['available']) * 100}
                 for name in mem_metrics:
                     self.gauge(name, mem_metrics[name], dimensions=dims_customer,
                                delegated_tenant=instance_cache.get(inst_name)['tenant_id'],
@@ -680,26 +753,8 @@ class LibvirtCheck(AgentCheck):
             # Test instance's remote responsiveness (ping check) if possible
             if (self.init_config.get('vm_ping_check_enable')) and self.init_config.get('ping_check') and 'network' in instance_cache.get(inst_name):
                 for net in instance_cache.get(inst_name)['network']:
-
-                    ping_cmd = self.init_config.get('ping_check').replace('NAMESPACE',
-                                                                          net['namespace']).split()
-                    ping_cmd.append(net['ip'])
-                    dims_customer_ip = dims_customer.copy()
-                    dims_operations_ip = dims_operations.copy()
-                    dims_customer_ip['ip'] = net['ip']
-                    dims_operations_ip['ip'] = net['ip']
-                    with open(os.devnull, "w") as fnull:
-                        try:
-                            self.log.debug("Running ping test: {0}".format(' '.join(ping_cmd)))
-                            res = subprocess.call(ping_cmd,
-                                                  stdout=fnull,
-                                                  stderr=fnull)
-                            self.gauge('ping_status', res, dimensions=dims_customer_ip,
-                                       delegated_tenant=instance_cache.get(inst_name)['tenant_id'],
-                                       hostname=instance_cache.get(inst_name)['hostname'])
-                            self.gauge('vm.ping_status', res, dimensions=dims_operations_ip)
-                        except OSError as e:
-                            self.log.warn("OS error running '{0}' returned {1}".format(ping_cmd, e))
+                    ping_args = [dims_customer, dims_operations, inst_name, instance_cache, net]
+                    ping_results.append(self.pool.apply_async(self._run_ping, ping_args))
 
         # Save these metrics for the next collector invocation
         self._update_metric_cache(metric_cache, math.ceil(time.time() - time_start))
@@ -708,6 +763,9 @@ class LibvirtCheck(AgentCheck):
         for gauge in agg_gauges:
             self.gauge(agg_gauges[gauge], agg_values[gauge], dimensions=dims_base)
 
+        # Check results of ping tests
+        self._check_ping_results(ping_results)
+
     def _calculate_rate(self, current_value, cache_value, time_diff):
         """Calculate rate based on current, cache value and time_diff."""
         try:
