@@ -127,11 +127,6 @@ class OvsCheck(AgentCheck):
                 ctr_cache[ifx][metric_name] = {
                     'timestamp': sample_time,
                     'value': value}
-        if not ifx_deltas:
-            # There is a chance that after all the neutron ports are empty still
-            # port cache value might exists for the old ports
-            self._update_port_cache()
-        #
         # Done collecting current rates and updating the cache file,
         # let's publish.
         #
@@ -163,6 +158,10 @@ class OvsCheck(AgentCheck):
                 continue
             if is_router_port:
                 router_name = port_info['router_name']
+                if not router_name:
+                    log_msg = "Missing router name for router_uuid {0} -- skipping."
+                    self.log.error(log_msg.format(device_uuid))
+                    continue
                 ifx_dimensions = {'resource_id': device_uuid,
                                   'port_id': port_uuid,
                                   'router_name': router_name}
@@ -175,6 +174,13 @@ class OvsCheck(AgentCheck):
             for metric_name, idx in self._get_metrics_map(measure).iteritems():
                 # POST to customer project
                 interface_stats_key = self._get_interface_stats_key(idx, metric_name, measure, ifx)
+                if interface_stats_key not in value:
+                    #
+                    # If we've skipped a given metric above due to
+                    # counter rollover/negative value, we won't have
+                    # a value to publish for that metric this round.
+                    #
+                    continue
                 customer_dimensions = this_dimensions.copy()
                 del customer_dimensions['hostname']
                 if is_router_port:
