@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# (C) Copyright 2015,2016 Hewlett Packard Enterprise Development Company LP
+# (C) Copyright 2015,2016 Hewlett Packard Enterprise Development LP
 """
     Licensed under Simplified BSD License (see LICENSE)
     (C) Boxed Ice 2010 all rights reserved
@@ -30,7 +30,6 @@ import tornado.web
 
 # agent import
 import monasca_agent.common.config as cfg
-import monasca_agent.common.metrics as metrics
 import monasca_agent.common.util as util
 import monasca_agent.forwarder.api.monasca_api as mon
 
@@ -55,9 +54,9 @@ class AgentInputHandler(tornado.web.RequestHandler):
         """
         global message_batch
 
-        msg = tornado.escape.json_decode(self.request.body)
         try:
-            message_batch.extend([metrics.Measurement(**m) for m in msg])
+            msg = tornado.escape.json_decode(self.request.body)
+            message_batch.extend(msg)
         except Exception:
             log.exception('Error parsing body of Agent Input')
             raise tornado.web.HTTPError(500)
