@@ -1,3 +1,5 @@
+# (C) Copyright 2015 Hewlett Packard Enterprise Development Company LP
+
 import logging
 import os
 import re
@@ -30,7 +32,9 @@ class Ntp(monasca_setup.detection.Plugin):
             if match is None:
                 ntp_server = 'pool.ntp.org'
             else:
-                ntp_server = match.group(1)
+                # There can be additional options after the server hostname or IP Address
+                server_val = match.group(1)
+                ntp_server = server_val.split()[0]
         else:
             ntp_server = 'pool.ntp.org'
         if re.match('^127', ntp_server):
