@@ -60,6 +60,18 @@ def find_process_name(pname):
     return None
 
 
+def find_process_service(sname):
+    """Simple function to call systemctl (service) to check if a service is running.
+    """
+    try:
+        subprocess.check_call(['service', sname, 'status'], stdout=PIPE, stderr=PIPE)
+        return True
+    except subprocess.CalledProcessError:
+        return False
+
+    return False
+
+
 def find_addr_listening_on_port(port):
     """Return the IP address which is listening on the specified TCP port."""
     for conn in psutil.net_connections(kind='tcp'):
@@ -109,7 +121,7 @@ def watch_process_by_username(username, process_name, service=None, component=No
     return config
 
 
-def watch_file_size(directory_name, file_names, file_recursive,
+def watch_file_size(directory_name, file_names, file_recursive=False,
                     service=None, component=None):
     """Takes a directory, a list of files, recursive flag and returns a
         Plugins object with the config set.
